@@ -1,4 +1,37 @@
 
+def extract_tags(tags):
+    return [tag.strip().lower() for tag in tags.split(',')]
+
+
+def append_tags(tags, new_tag):
+    if tags:
+        split_tags = tags.split(',')
+        split_tags.append(f' {new_tag}')
+        return ','.join(split_tags)
+    return new_tag
+
+
+def tag_resource(client, resource, new_tag, resource_type=None):
+    resource_id = int([resource_type]['id'])
+    updated_tags = append_tags(resource['tags'], new_tag)
+    tag_data = {
+        resource_type: {
+            "id": resource_id,
+            "tags": updated_tags
+        }
+    }
+    url = f'{client.api_path}/{resource_type}/{resource_id}.json'
+    return client.put(url, json=tag_data).status_code
+
+
+def get_customer_by_id(client, customer_id):
+    return client.get(f'{client.api_path}/customers/{customer_id}.json').json()['customer']
+
+
+def get_order_by_id(client, order_id):
+    return client.get(f'{client.api_path}/orders/{order_id}.json').json()['order']
+
+
 def get_webhooks(client):
     return client.get(f'{client.api_path}/webhooks.json').json()['webhooks']
 
